autowisp.database.data_model.base module — AutoWISP documentation

# autowisp.database.data_model.base module

## Class Inheritance Diagram

Declare the base class for all table classes.

class autowisp.database.data_model.base.DataModelBase(**kwargs: Any)

  Bases: `DeclarativeBase`

  The base class for all table classes.

  describe_table()

    Return description of the table in human readable form.

  id = Column(None, Integer(), table=None, primary_key=True, nullable=False)
  metadata: ClassVar[MetaData] = MetaData()

    Refers to the `_schema.MetaData` collection that will be used for new `_schema.Table` objects.

    See also

    orm_declarative_metadata

  registry: ClassVar[_RegistryType] = <sqlalchemy.orm.decl_api.registry object>

    Refers to the `_orm.registry` in use where new `_orm.Mapper` objects will be associated.

  timestamp = Column(None, TIMESTAMP(), table=None, nullable=False, server_default=DefaultClause(<sqlalchemy.sql.elements.TextClause object>, for_update=False))